@@ -5,6 +5,8 @@
 */
 
 #include "importmailjobinterfacetest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "archivestorage.h"
 #include "importmailjobinterfacetestimpl.h"
 #include "testimportfile.h"
@@ -25,30 +27,29 @@ void ImportMailJobInterfaceTest::importMail_data()
     Utils::StoredTypes options = {Utils::StoredType::Config};
     const QByteArray pathConfig(QByteArray(PIMDATAEXPORTER_DIR) + "/import/");
 
-    QTest::newRow("mailonlyconfig") << QString::fromLatin1(pathConfig) << QStringLiteral("/mailonlyconfig/") << options;
+    QTest::newRow("mailonlyconfig") << QString::fromLatin1(pathConfig) << u"/mailonlyconfig/"_s << options;
 
     options = {Utils::StoredType::Config | Utils::StoredType::Resources};
-    QTest::newRow("mailconfigandresource") << QString::fromLatin1(pathConfig) << QStringLiteral("mailconfigandresource/") << options;
+    QTest::newRow("mailconfigandresource") << QString::fromLatin1(pathConfig) << u"mailconfigandresource/"_s << options;
 
     options = {Utils::StoredType::MailTransport};
-    QTest::newRow("mailtransport") << QString::fromLatin1(pathConfig) << QStringLiteral("mailtransport/") << options;
+    QTest::newRow("mailtransport") << QString::fromLatin1(pathConfig) << u"mailtransport/"_s << options;
 
     options = {Utils::StoredType::MailTransport};
-    QTest::newRow("mailtransport2") << QString::fromLatin1(pathConfig) << QStringLiteral("mailtransport2/") << options;
+    QTest::newRow("mailtransport2") << QString::fromLatin1(pathConfig) << u"mailtransport2/"_s << options;
 
     options = {Utils::StoredType::Identity};
-    QTest::newRow("identities") << QString::fromLatin1(pathConfig) << QStringLiteral("identities/") << options;
+    QTest::newRow("identities") << QString::fromLatin1(pathConfig) << u"identities/"_s << options;
 
     options = {Utils::StoredType::Config | Utils::StoredType::Identity};
-    QTest::newRow("identitiesandconfig") << QString::fromLatin1(pathConfig) << QStringLiteral("identitiesandconfig/") << options;
+    QTest::newRow("identitiesandconfig") << QString::fromLatin1(pathConfig) << u"identitiesandconfig/"_s << options;
 
     options = {Utils::StoredType::Config | Utils::StoredType::Identity | Utils::StoredType::MailTransport};
-    QTest::newRow("identitiesandconfigandmailtransport")
-        << QString::fromLatin1(pathConfig) << QStringLiteral("identitiesandconfigandmailtransport/") << options;
+    QTest::newRow("identitiesandconfigandmailtransport") << QString::fromLatin1(pathConfig) << u"identitiesandconfigandmailtransport/"_s << options;
 
     options = {Utils::StoredType::Config | Utils::StoredType::Identity | Utils::StoredType::MailTransport | Utils::StoredType::Resources | Utils::Mails};
     QTest::newRow("identitiesandconfigandmailtransportandresources")
-        << QString::fromLatin1(pathConfig) << QStringLiteral("identitiesandconfigandmailtransportandresources/") << options;
+        << QString::fromLatin1(pathConfig) << u"identitiesandconfigandmailtransportandresources/"_s << options;
 }
 
 void ImportMailJobInterfaceTest::importMail()
@@ -59,13 +60,13 @@ void ImportMailJobInterfaceTest::importMail()
     const QString fullTestPath = zipFilePath + testPath;
     auto file = new TestImportFile(fullTestPath, this);
     file->setPathConfig(fullTestPath);
-    file->setExtractPath(QDir::tempPath() + QLatin1Char('/') + testPath);
+    file->setExtractPath(QDir::tempPath() + u'/' + testPath);
     file->setExcludePath(Utils::mailsPath()); // ???
     auto impl = new ImportMailJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
     impl->setPathConfig(file->pathConfig());
     impl->setExtractPath(file->extractPath());
     impl->setTempDirName(file->extractPath());
-    impl->setExistingPathConfig(fullTestPath + QStringLiteral("/existingconfig/"));
+    impl->setExistingPathConfig(fullTestPath + u"/existingconfig/"_s);
     file->setAbstractImportExportJob(impl);
     file->setLoggingFilePath(impl->loggingFilePath());
     file->start();
